@@ -2,7 +2,7 @@
 
 """
     AUTHOR: Igor Kalnitsky <igor.kalnitsky@gmail.com>
-    URL: http://www.kalnitsky.org.ua/
+    URL: http://www.kalnitsky.org/
 """
 
 import nautilus
